==> brmo-stufbg204-1.5.1-sources.jar: nl/egem/stuf/sector/bg/_0204/HHDVraag.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * huishouden binnen vraagberichten
 * 
 * <p>Java class for HHD-vraag complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HHD-vraag">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHD-fund">
 *       &lt;sequence>
 *         &lt;element name="HHDPRS" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHDPRS-rel">
 *                 &lt;sequence>
 *                   &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kennisgeving"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="HDDWOZ" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;sequence>
 *                   &lt;element name="WOZ" type="{http://www.egem.nl/StUF/sector/bg/0204}WOZ-kennisgeving"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HHD-vraag", propOrder = {
    "hhdprs",
    "hddwoz"
})
public class HHDVraag
    extends HHDFund
{

    @XmlElementRef(name = "HHDPRS", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<HHDVraag.HHDPRS> hhdprs;
    @XmlElementRef(name = "HDDWOZ", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<HHDVraag.HDDWOZ> hddwoz;

    /**
     * Gets the value of the hhdprs property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link HHDVraag.HHDPRS }{@code >}
     *     
     */
    public JAXBElement<HHDVraag.HHDPRS> getHHDPRS() {
        return hhdprs;
    }

    /**
     * Sets the value of the hhdprs property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link HHDVraag.HHDPRS }{@code >}
     *     
     */
    public void setHHDPRS(JAXBElement<HHDVraag.HHDPRS> value) {
        this.hhdprs = value;
    }

    /**
     * Gets the value of the hddwoz property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link HHDVraag.HDDWOZ }{@code >}
     *     
     */
    public JAXBElement<HHDVraag.HDDWOZ> getHDDWOZ() {
        return hddwoz;
    }

    /**
     * Sets the value of the hddwoz property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link HHDVraag.HDDWOZ }{@code >}
     *     
     */
    public void setHDDWOZ(JAXBElement<HHDVraag.HDDWOZ> value) {
        this.hddwoz = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;sequence>
     *         &lt;element name="WOZ" type="{http://www.egem.nl/StUF/sector/bg/0204}WOZ-kennisgeving"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "woz"
    })
    public static class HDDWOZ
        extends Relatie
    {

        @XmlElement(name = "WOZ", required = true, nillable = true)
        protected WOZKennisgeving woz;

        /**
         * Gets the value of the woz property.
         * 
         * @return
         *     possible object is
         *     {@link WOZKennisgeving }
         *     
         */
        public WOZKennisgeving getWOZ() {
            return woz;
        }

        /**
         * Sets the value of the woz property.
         * 
         * @param value
         *     allowed object is
         *     {@link WOZKennisgeving }
         *     
         */
        public void setWOZ(WOZKennisgeving value) {
            this.woz = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHDPRS-rel">
     *       &lt;sequence>
     *         &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kennisgeving"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "prs"
    })
    public static class HHDPRS
        extends HHDPRSRel
    {

        @XmlElement(name = "PRS", required = true, nillable = true)
        protected PRSKennisgeving prs;

        /**
         * Gets the value of the prs property.
         * 
         * @return
         *     possible object is
         *     {@link PRSKennisgeving }
         *     
         */
        public PRSKennisgeving getPRS() {
            return prs;
        }

        /**
         * Sets the value of the prs property.
         * 
         * @param value
         *     allowed object is
         *     {@link PRSKennisgeving }
         *     
         */
        public void setPRS(PRSKennisgeving value) {
            this.prs = value;
        }

    }

}

==> brmo-stufbg204-2.0.1-sources.jar: nl/egem/stuf/sector/bg/_0204/HHDVraag.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * huishouden binnen vraagberichten
 * 
 * <p>Java class for HHD-vraag complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HHD-vraag"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHD-fund"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="HHDPRS" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHDPRS-rel"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kennisgeving"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="HDDWOZ" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="WOZ" type="{http://www.egem.nl/StUF/sector/bg/0204}WOZ-kennisgeving"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HHD-vraag", propOrder = {
    "hhdprs",
    "hddwoz"
})
public class HHDVraag
    extends HHDFund
{

    @XmlElementRef(name = "HHDPRS", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<HHDVraag.HHDPRS> hhdprs;
    @XmlElementRef(name = "HDDWOZ", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<HHDVraag.HDDWOZ> hddwoz;

    /**
     * Gets the value of the hhdprs property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link HHDVraag.HHDPRS }{@code >}
     *     
     */
    public JAXBElement<HHDVraag.HHDPRS> getHHDPRS() {
        return hhdprs;
    }

    /**
     * Sets the value of the hhdprs property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link HHDVraag.HHDPRS }{@code >}
     *     
     */
    public void setHHDPRS(JAXBElement<HHDVraag.HHDPRS> value) {
        this.hhdprs = value;
    }

    /**
     * Gets the value of the hddwoz property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link HHDVraag.HDDWOZ }{@code >}
     *     
     */
    public JAXBElement<HHDVraag.HDDWOZ> getHDDWOZ() {
        return hddwoz;
    }

    /**
     * Sets the value of the hddwoz property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link HHDVraag.HDDWOZ }{@code >}
     *     
     */
    public void setHDDWOZ(JAXBElement<HHDVraag.HDDWOZ> value) {
        this.hddwoz = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="WOZ" type="{http://www.egem.nl/StUF/sector/bg/0204}WOZ-kennisgeving"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "woz"
    })
    public static class HDDWOZ
        extends Relatie
    {

        @XmlElement(name = "WOZ", required = true, nillable = true)
        protected WOZKennisgeving woz;

        /**
         * Gets the value of the woz property.
         * 
         * @return
         *     possible object is
         *     {@link WOZKennisgeving }
         *     
         */
        public WOZKennisgeving getWOZ() {
            return woz;
        }

        /**
         * Sets the value of the woz property.
         * 
         * @param value
         *     allowed object is
         *     {@link WOZKennisgeving }
         *     
         */
        public void setWOZ(WOZKennisgeving value) {
            this.woz = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}HHDPRS-rel"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kennisgeving"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "prs"
    })
    public static class HHDPRS
        extends HHDPRSRel
    {

        @XmlElement(name = "PRS", required = true, nillable = true)
        protected PRSKennisgeving prs;

        /**
         * Gets the value of the prs property.
         * 
         * @return
         *     possible object is
         *     {@link PRSKennisgeving }
         *     
         */
        public PRSKennisgeving getPRS() {
            return prs;
        }

        /**
         * Sets the value of the prs property.
         * 
         * @param value
         *     allowed object is
         *     {@link PRSKennisgeving }
         *     
         */
        public void setPRS(PRSKennisgeving value) {
            this.prs = value;
        }

    }

}
